/*
  configures the device for Linux (OSS) Music drivers.
  Copyright (C) 1998  Martin Vogt

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation.

  For more information look at the file COPYRIGHT in this package

 */





#include <devices/audioDeviceLinux.h>



AudioDeviceLinux::AudioDeviceLinux(char* device,int block):AudioDevice(device){
  this->device=device;
  fd=-1;
  owner=NULL;
  lBlocked=block;
  lNeedInit=true;
  lWithReopen=false;
}


AudioDeviceLinux::~AudioDeviceLinux() {
}


char* AudioDeviceLinux::getNodeName() {
  return "AudioDeviceLinux";
}


int AudioDeviceLinux::openDevice() {
  cout <<"openDevice (OSS) -s"<<endl;
  if (lBlocked == false) {
    fd=::open(device,O_WRONLY | O_NONBLOCK,0); 
  } else {
    fd=::open(device,O_WRONLY ,0);  
  }
  cout <<"openDevice (OSS) -e: fd "<<fd<<endl;
  lNeedInit=true;
  getPreferredBufferSize();
  return fd;
}


int AudioDeviceLinux::closeDevice() {
  cout <<"closeDevice (OSS) -s"<<endl;
  int ret;
  if (fd != -1) {
    ret=::close(fd);
  }
  fd=-1;
  cout <<"closeDevice (OSS) -e"<<endl;
  return ret;
}

  

int AudioDeviceLinux::getPreferredBufferSize() {
  if (fd == -1) {
    cout <<"device not ready!"<<endl;
    return 0;
  }
  IOCTL(fd,SNDCTL_DSP_GETBLKSIZE,buffersize);
  cout <<"***************  prefered Buffersize :"<< buffersize<<endl;
  return buffersize;
}


int AudioDeviceLinux::needInit(DeviceConfig* buf) {
  int back;
  back=AudioDevice::needInit(buf);
  back=lNeedInit || back;
  return back;
}


void AudioDeviceLinux::setDeviceConfig(DeviceConfig* buf) {
  int stereo;
  int sampleSize;
  int speed;
  YafAudioInfo* newInfo;
  newInfo=buf->getAudioInfo();

  setAudioInfo(newInfo);

  stereo=newInfo->getStereo();
  sampleSize=newInfo->getSampleSize();
  speed=newInfo->getSpeed();

  if (fd == -1) {
    cout << "cannot init Device. not open!"<<endl;
    return;
  }

  cout << "initDSP-> stereo:" << stereo
       << "sample:"<< sampleSize 
       << "speed: "<< speed 
       <<endl;
  if (lWithReopen==true) {
    closeDevice();
    openDevice();
    lWithReopen=false;
  }

  ioctl(fd,SNDCTL_DSP_RESET,NULL);
  IOCTL(fd,SNDCTL_DSP_STEREO,stereo);
  IOCTL(fd,SNDCTL_DSP_SAMPLESIZE,sampleSize);
  IOCTL(fd,SNDCTL_DSP_SPEED,speed);
  lNeedInit=false;
}

 

int AudioDeviceLinux::rawWrite(char* buf,int len) {
  int didWrite;
  if (fd < 0) {
    cout << "Device :"<<device <<" not open!"<<endl;
    return len;
  }
  didWrite=::write(fd,buf,len);
  if (didWrite != buffersize) {
    cout << "Write "<<didWrite<<" != prefferred Buffsize ! "<<buffersize<<endl;
    //lNeedInit=true;
  }
  return didWrite;
}






