//
//  Kmpg
// 
//  Copyright (C) 1997 Bjarni Ivarsson
//  email: Bjarni.Ivarsson@swipnet.se
// 
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#include <iostream.h>
#include <qpainter.h>
#include <qtooltip.h>
#include <qregexp.h>

#include "infoline.h"
#include "info_pixmaps.h"

#define BGCOLOR 0,0,0
#define COLOR1  0,0,0
#define COLOR2  0,0,0
#define COLOR3  0,255,0
#define COLOR4  255,255,0

#define FONT     "helvetica"
#define FONTSIZE 10

#define LBORDER  3
#define RBORDER  3
#define LINES    2

InfoLine::InfoLine( QWidget *parent, PlaylistMgr* mgr, int width ):
   QWidget( parent )
{
   _mgr = mgr;
   _width = width;

   QFont _font( FONT, FONTSIZE );
   QFontMetrics _fontmetrics( _font );
   _lineheight = _fontmetrics.height();
   _height = _lineheight*LINES;
   _textposy = (int)(_lineheight/4.0+0.8)+_lineheight/2;
   setFixedSize( _width, _height);
   resize( _width, _height );
   pm_back.resize( _width, _height );
   pm_back.fill(QColor(BGCOLOR));
   setBackgroundPixmap( pm_back );
   scrollTimer = new QTimer( this , "scrolltimer" );
   connect( scrollTimer, SIGNAL(timeout()), SLOT(scrollTimeout()) );
}

InfoLine::~InfoLine()
{
   delete scrollTimer;
}

void InfoLine::setInfo( Fileinfo &_finfo )
{
   QPainter paint;
   QString string;
   int x;

   QFont _font(FONT, FONTSIZE);
   QFontMetrics _fontmetrics(_font);

   scrollTimer->stop();
   paint.begin( &pm_back );
   paint.fillRect(0,0,_width,_height,QBrush(QColor(COLOR1)));
   paint.setPen( QColor(COLOR3) );
   paint.setFont( _font );

   QPixmap pm_stereo(stereo_xpm);
   QPixmap pm_mono(mono_xpm);
   QPixmap pm_copyright(copyright_xpm);
   QPixmap pm_nocopyright(nocopyright_xpm);
   QPixmap pm_copy(copy_xpm);
   QPixmap pm_original(original_xpm);

   int x_pos = LBORDER;
   int y_pos = (_lineheight-pm_original.height())/2;
   if( _finfo.getCopyright() )
      bitBlt( &pm_back, x_pos, y_pos, &pm_copyright );
   else
      bitBlt( &pm_back, x_pos, y_pos, &pm_nocopyright );

   x_pos += pm_copyright.width()+1;
   y_pos = (_lineheight-pm_original.height())/2;
   if( _finfo.getOriginal() )
      bitBlt( &pm_back, x_pos, y_pos, &pm_original );
   else
      bitBlt( &pm_back, x_pos, y_pos, &pm_copy );

   x_pos += pm_original.width()+1;
   y_pos = (_lineheight-pm_original.height())/2;
   if( _finfo.getChannels() == 2 )
      bitBlt( &pm_back, x_pos, y_pos, &pm_stereo );
   else
      bitBlt( &pm_back, x_pos, y_pos, &pm_mono );

   x_pos += pm_stereo.width()+2;
   string = _finfo.getFrequency();
   string += ", ";
   string += _finfo.getBitrate();
   string += ", ";
   string += _finfo.getVersion();
   string += " Layer ";
   string += _finfo.getLayer();

   paint.drawText( x_pos, _textposy, string );
   paint.end();

   {
      int i;
      int sec = (int)(_finfo.getMinNumberOfFrames()* _finfo.getMsPerFrame()/ 1000+0.5);
      QRegExp r = QRegExp( ".mp[123]", FALSE, FALSE );
      QString s2;

      string = _finfo.getName();
      i = string.findRev( r );
      if( i!=-1)
	 string.remove(i, string.length());
      string += " [";
      s2.setNum(sec/60);
      string += s2;
      string += ":";
      if( (sec%60)<10 )
	 string += "0";
      s2.setNum(sec%60);
      string += s2;
      string += "]";
   }
   
   pm_filename.resize( _fontmetrics.width(string), _lineheight );
   if (pm_filename.width()>(_width-RBORDER-LBORDER-2)) 
      pm_filename.resize( _fontmetrics.width(string)+40, _lineheight );
   else
       pm_filename.resize( _width-RBORDER-LBORDER, _lineheight );
   pm_filename.fill(QColor(COLOR2));
   paint.begin( &pm_filename );
   paint.setPen( QColor(COLOR4) );
   paint.setFont( _font );
   paint.drawText( LBORDER, _textposy, string );
   paint.end();

   setBackgroundPixmap( pm_back );
   scrollPos = 0;
   scrollInc = 1;
   if (pm_filename.width()>(_width-RBORDER-LBORDER))
      scrollTimer->start(60);
   else
      scrollTimeout();
}

void InfoLine::scrollTimeout()
{
   scrollPos += scrollInc;
   if (scrollPos >= pm_filename.width())
      scrollPos = 0;
   bitBlt( &pm_back, LBORDER, _lineheight, &pm_filename, scrollPos, 0, (_width-RBORDER-LBORDER), _lineheight );
   if ((pm_filename.width()-scrollPos) < (_width-RBORDER-LBORDER))
      bitBlt( &pm_back, LBORDER + (pm_filename.width()-scrollPos), _lineheight, &pm_filename,
	      0, 0, (_width-RBORDER-LBORDER) - (pm_filename.width()-scrollPos), _lineheight );	
    setBackgroundPixmap( pm_back );
}

void InfoLine::doUpdate( int index, QString str)
{
}

void InfoLine::doClear()
{
}

void InfoLine::resizeInfoLine()
{
//   emit( sigSizeChanged() );
}
