//
//  Kmpg
// 
//  Copyright (C) 1997 Bjarni Ivarsson
//  email: Bjarni.Ivarsson@swipnet.se
// 
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#include <iostream.h>
#include <qpainter.h>
#include <qtooltip.h>
#include <qregexp.h>

#include "statusline.h"

//#define BGCOLOR 255,255,255
//#define COLOR1  127,127,127
//#define COLOR2  64,64,64  
#define BGCOLOR 0,0,0
#define COLOR1  0,0,0
#define COLOR2  0,0,0
#define COLOR3  0,255,0
#define COLOR4  255,255,0

#define FONT     "helvetica"
#define FONTSIZE 10

#define LBORDER  3
#define RBORDER  3
#define LINES    1
#define FIELDS   4

StatusLine::StatusLine( QWidget *parent, int width ):
   QWidget( parent )
{
   _width = width;

   QFont _font( FONT, FONTSIZE );
   QFontMetrics _fontmetrics( _font );
   _lineheight = _fontmetrics.height();
   _fieldwidth = (int)((_width-LBORDER-RBORDER-FIELDS+1)/FIELDS+0.5);
   _height = _lineheight*LINES;
   _textposy = (int)(_lineheight/4.0+0.8)+_lineheight/2;

   setFixedSize( _width, _height);
   resize( _width, _height );
   pm_back.resize( _width, _height );
   pm_back.fill(QColor(BGCOLOR));
   setBackgroundPixmap( pm_back );
}

StatusLine::~StatusLine()
{
}

void StatusLine::setField (int field, QString string )
{
   QPainter paint;
   QPixmap pm;
   int x;

   QFont _font(FONT, FONTSIZE);
   QFontMetrics _fontmetrics(_font);

   pm.resize(_fieldwidth,_lineheight);

   paint.begin( &pm );
   paint.fillRect(0,0,_fieldwidth*(field+1),_height,QBrush(QColor(COLOR1)));
   paint.setPen( QColor(COLOR3) );
   paint.setFont( _font );

   int x_pos = 0;
   if ( field > 0 && field < (FIELDS-1) )
      x_pos += (_fieldwidth - _fontmetrics.width(string))/2;
   else if ( field == (FIELDS-1) )
      x_pos += _fieldwidth - _fontmetrics.width(string);

   paint.drawText( x_pos, _textposy, string );
   paint.end();
   bitBlt(&pm_back, _fieldwidth*field+(_width-_fieldwidth*FIELDS-FIELDS+1)/2+field, 0, &pm );

   setBackgroundPixmap( pm_back );
}

void StatusLine::doClear()
{
   QPainter paint;
   QString string;
   int x;

   QFont _font(FONT, FONTSIZE);
   QFontMetrics _fontmetrics(_font);

   paint.begin( &pm_back );
   paint.fillRect(0,0,_width,_height,QBrush(QColor(COLOR1)));
   paint.end();

   setBackgroundPixmap( pm_back );
}

void StatusLine::mousePressEvent( QMouseEvent *e )
{
   emit(statusLineClicked(e->x()/(_fieldwidth+LBORDER+1)));
}  
